@@ -1,9 +1,10 @@
 class SlashCommandError(Exception):
     """
     All exceptions of this extension can be captured with this.
-    Note that discord.py doesn't trigger `on_command_error` event.
+
+    .. note::
+        discord.py doesn't trigger `on_command_error` event. Use this extension's `on_slash_command_error`.
     """
-    pass
 
 
 class RequestFailure(SlashCommandError):
@@ -27,8 +28,6 @@ class IncorrectFormat(SlashCommandError):
     """
     Some formats are incorrect. See Discord API DOCS for proper format.
     """
-    def __init__(self, msg: str):
-        super().__init__(msg)
 
 
 class DuplicateCommand(SlashCommandError):
@@ -37,3 +36,21 @@ class DuplicateCommand(SlashCommandError):
     """
     def __init__(self, name: str):
         super().__init__(f"Duplicate command name detected: {name}")
+
+
+class DuplicateSlashClient(SlashCommandError):
+    """
+    There are duplicate :class:`.SlashCommand` instances.
+    """
+
+
+class CheckFailure(SlashCommandError):
+    """
+    Command check has failed.
+    """
+
+
+class IncorrectType(SlashCommandError):
+    """
+    Type passed was incorrect
+    """
