@@ -1,7 +1,10 @@
 import typing
+import inspect
 import asyncio
 import aiohttp
-from ..error import RequestFailure
+from ..error import RequestFailure, IncorrectType
+from ..model import SlashCommandOptionType
+from collections.abc import Callable
 
 
 async def add_slash_command(bot_id,
@@ -27,7 +30,7 @@ async def add_slash_command(bot_id,
     base = {
         "name": cmd_name,
         "description": description,
-        "options": options if options else []
+        "options": options or []
     }
 
     async with aiohttp.ClientSession() as session:
@@ -71,7 +74,7 @@ async def remove_slash_command(bot_id,
 
 async def get_all_commands(bot_id,
                            bot_token,
-                           guild_id):
+                           guild_id=None):
     """
     A coroutine that sends a slash command get request to Discord API.
 
@@ -107,7 +110,7 @@ async def remove_all_commands(bot_id,
 
     await remove_all_commands_in(bot_id, bot_token, None)
 
-    for x in guild_ids if guild_ids else []:
+    for x in guild_ids or []:
         try:
             await remove_all_commands_in(bot_id, bot_token, x)
         except RequestFailure:
@@ -141,7 +144,7 @@ async def remove_all_commands_in(bot_id,
 
 def create_option(name: str,
                   description: str,
-                  option_type: int,
+                  option_type: typing.Union[int, type],
                   required: bool,
                   choices: list = None) -> dict:
     """
@@ -154,15 +157,62 @@ def create_option(name: str,
     :param choices: Choices of the option. Can be empty.
     :return: dict
     """
+    if not isinstance(option_type, int) or isinstance(option_type, bool): #Bool values are a subclass of int
+        original_type = option_type
+        option_type = SlashCommandOptionType.from_type(original_type)
+        if option_type is None:
+            raise IncorrectType(f"The type {original_type} is not recognized as a type that Discord accepts for slash commands.")
     return {
         "name": name,
         "description": description,
         "type": option_type,
         "required": required,
-        "choices": choices if choices else []
+        "choices": choices or []
     }
 
 
+def generate_options(function: Callable, description: str = "No description.", connector: dict = None) -> list:
+    """
+    Generates a list of options from the type hints of a command.
+    You currently can type hint: str, int, bool, discord.User, discord.Channel, discord.Role
+
+    .. warning::
+        This is automatically used if you do not pass any options directly. It is not recommended to use this.
+
+    :param function: The function callable of the command.
+    :param description: The default argument description.
+    :param connector: Kwargs connector of the command.
+    """
+    options = []
+    if connector:
+        connector = {y: x for x, y in connector.items()} # Flip connector.
+    params = iter(inspect.signature(function).parameters.values())
+    if next(params).name in ("self", "cls"):
+        # Skip 1. (+ 2.) parameter, self/cls and ctx
+        next(params)
+
+    for param in params:
+        required = True
+        if isinstance(param.annotation, str):
+            # if from __future__ import annotations, then annotations are strings and should be converted back to types
+            param = param.replace(annotation=eval(param.annotation, function.__globals__))
+
+        if param.default is not inspect._empty:
+            required = False
+        elif getattr(param.annotation, "__origin__", None) is typing.Union:
+            # Make a command argument optional with typing.Optional[type] or typing.Union[type, None]
+            args = getattr(param.annotation, "__args__", None)
+            if args:
+                param = param.replace(annotation=args[0])
+                required = not args[-1] is type(None)
+
+        option_type = SlashCommandOptionType.from_type(param.annotation) or SlashCommandOptionType.STRING
+        name = param.name if not connector else connector[param.name]
+        options.append(create_option(name, description or "No Description.", option_type, required))
+
+    return options
+
+
 def create_choice(value: str, name: str):
     """
     Creates choices used for creating command option.
